@@ -1,4 +1,7 @@
-class HeaderKeys:
+from enum import Enum
+
+
+class HeaderKeys(str, Enum):
     correlation_id = "X-Correlation-ID"
     request_id = "X-Request-ID"
     date = "Date"
