@@ -1,7 +1,6 @@
-# flake8: noqa
+from .base import Plugin
 from .correlation_id import CorrelationIdPlugin
 from .date_header import DateHeaderPlugin
 from .forwarded_for import ForwardedForPlugin
-from .plugin import Plugin
 from .request_id import RequestIdPlugin
 from .user_agent import UserAgentPlugin
